@@ -1,7 +1,7 @@
 package Bencher::Scenario::PerinciEnvRes;
 
-our $DATE = '2016-06-26'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $DATE = '2017-01-25'; # DATE
+our $VERSION = '0.05'; # VERSION
 
 our $scenario = {
     summary => 'Compare returning enveloped result vs naked/list',
@@ -27,10 +27,14 @@ Bencher::Scenario::PerinciEnvRes - Compare returning enveloped result vs naked/l
 
 =head1 VERSION
 
-This document describes version 0.04 of Bencher::Scenario::PerinciEnvRes (from Perl distribution Bencher-Scenarios-Perinci), released on 2016-06-26.
+This document describes version 0.05 of Bencher::Scenario::PerinciEnvRes (from Perl distribution Bencher-Scenarios-Perinci), released on 2017-01-25.
 
 =head1 SYNOPSIS
 
+=head1 DESCRIPTION
+
+Packaging a benchmark script as a Bencher scenario makes it convenient to include/exclude/add participants/datasets (either via CLI or Perl code), send the result to a central repository, among others . See L<Bencher> and L<bencher> (CLI) for more details.
+
 =head1 BENCHMARK PARTICIPANTS
 
 =over
@@ -71,22 +75,22 @@ Code template:
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.22.2 >>, CPU: I<< Intel(R) Core(TM) i7-4770 CPU @ 3.40GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
+Run on: perl: I<< v5.24.0 >>, CPU: I<< Intel(R) Core(TM) M-5Y71 CPU @ 1.20GHz (2 cores) >>, OS: I<< GNU/Linux LinuxMint version 17.3 >>, OS kernel: I<< Linux version 3.19.0-32-generic >>.
 
 Benchmark with default options (C<< bencher -m PerinciEnvRes >>):
 
+ #table1#
  +---------------------+-----------+-----------+------------+---------+---------+
  | participant         | rate (/s) | time (ns) | vs_slowest |  errors | samples |
  +---------------------+-----------+-----------+------------+---------+---------+
- | envres_with_resmeta |   3444520 |   290.317 |     1      |   0     |      20 |
- | envres              |   5198820 |   192.351 |     1.5093 |   0     |      21 |
- | list                | 130000000 |     7.4   |    39      | 2.6e-11 |      20 |
- | str                 | 400000000 |     2     |   100      | 2.6e-11 |      20 |
+ | envres_with_resmeta |   2990000 |       334 |        1   | 1.4e-10 |      20 |
+ | envres              |   4300000 |       230 |        1.4 | 3.9e-10 |      36 |
+ | list                |  61000000 |        16 |       21   |   5e-11 |      30 |
+ | str                 | 200000000 |         5 |       70   | 2.7e-10 |      20 |
  +---------------------+-----------+-----------+------------+---------+---------+
 
-=head1 DESCRIPTION
 
-Packaging a benchmark script as a Bencher scenario makes it convenient to include/exclude/add participants/datasets (either via CLI or Perl code), send the result to a central repository, among others . See L<Bencher> and L<bencher> (CLI) for more details.
+To display as an interactive HTML table on a browser, you can add option C<--format html+datatables>.
 
 =head1 HOMEPAGE
 
@@ -110,7 +114,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
