@@ -1,12 +1,12 @@
 package Bencher::Scenario::PerinciSubNormalize;
 
-our $DATE = '2016-06-26'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $DATE = '2017-01-25'; # DATE
+our $VERSION = '0.05'; # VERSION
 
 our $scenario = {
     summary => 'Benchmark normalizing Rinci function metadata',
     modules => {
-        'Perinci::Sub::Normalize' => {version=>0.18},
+        'Perinci::Sub::Normalize' => {version=>0.19},
     },
     participants => [
         {
@@ -132,7 +132,7 @@ Bencher::Scenario::PerinciSubNormalize
 
 =head1 VERSION
 
-This document describes version 0.04 of Bencher::Scenario::PerinciSubNormalize (from Perl distribution Bencher-Scenarios-Perinci), released on 2016-06-26.
+This document describes version 0.05 of Bencher::Scenario::PerinciSubNormalize (from Perl distribution Bencher-Scenarios-Perinci), released on 2017-01-25.
 
 =head1 SYNOPSIS
 
@@ -146,11 +146,15 @@ To run module startup overhead benchmark:
 
 For more options (dump scenario, list/include/exclude/add participants, list/include/exclude/add datasets, etc), see L<bencher> or run C<bencher --help>.
 
+=head1 DESCRIPTION
+
+Packaging a benchmark script as a Bencher scenario makes it convenient to include/exclude/add participants/datasets (either via CLI or Perl code), send the result to a central repository, among others . See L<Bencher> and L<bencher> (CLI) for more details.
+
 =head1 BENCHMARKED MODULES
 
 Version numbers shown below are the versions used when running the sample benchmark.
 
-L<Perinci::Sub::Normalize> 0.18
+L<Perinci::Sub::Normalize> 0.19
 
 =head1 BENCHMARK PARTICIPANTS
 
@@ -186,32 +190,33 @@ Only contains v=>1.1
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.22.2 >>, CPU: I<< Intel(R) Core(TM) i7-4770 CPU @ 3.40GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
+Run on: perl: I<< v5.24.0 >>, CPU: I<< Intel(R) Core(TM) M-5Y71 CPU @ 1.20GHz (2 cores) >>, OS: I<< GNU/Linux LinuxMint version 17.3 >>, OS kernel: I<< Linux version 3.19.0-32-generic >>.
 
 Benchmark with default options (C<< bencher -m PerinciSubNormalize >>):
 
+ #table1#
  +---------+-----------+-----------+------------+---------+---------+
  | dataset | rate (/s) | time (μs) | vs_slowest |  errors | samples |
  +---------+-----------+-----------+------------+---------+---------+
- | typical |     13000 |     78    |        1   | 3.1e-07 |      25 |
- | 1arg    |     55000 |     18    |        4.3 | 2.7e-08 |      20 |
- | 0args   |    120000 |      8.3  |        9.4 | 1.3e-08 |      21 |
- | minimal |    283000 |      3.53 |       22.2 | 1.6e-09 |      22 |
+ | typical |      8200 |   120     |       1    | 2.7e-07 |      20 |
+ | 1arg    |     35000 |    29     |       4.3  | 5.3e-08 |      20 |
+ | 0args   |     77000 |    13     |       9.4  | 3.3e-08 |      20 |
+ | minimal |    180400 |     5.542 |      22.13 | 3.5e-10 |      20 |
  +---------+-----------+-----------+------------+---------+---------+
 
 
 Benchmark module startup overhead (C<< bencher -m PerinciSubNormalize --module-startup >>):
 
- +-------------------------+-----------+------------------------+------------+---------+---------+
- | participant             | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors | samples |
- +-------------------------+-----------+------------------------+------------+---------+---------+
- | Perinci::Sub::Normalize |       5   |                    2.5 |          1 | 1.2e-05 |      20 |
- | perl -e1 (baseline)     |       2.5 |                    0   |          2 | 8.7e-06 |      20 |
- +-------------------------+-----------+------------------------+------------+---------+---------+
+ #table2#
+ +-------------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
+ | participant             | proc_private_dirty_size (kB) | proc_rss_size (MB) | proc_size (MB) | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors | samples |
+ +-------------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
+ | Perinci::Sub::Normalize | 844                          | 4                  | 16             |       9.4 |                    3.6 |        1   | 5.5e-05 |      20 |
+ | perl -e1 (baseline)     | 1044                         | 4.4                | 16             |       5.8 |                    0   |        1.6 | 9.6e-06 |      20 |
+ +-------------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
 
-=head1 DESCRIPTION
 
-Packaging a benchmark script as a Bencher scenario makes it convenient to include/exclude/add participants/datasets (either via CLI or Perl code), send the result to a central repository, among others . See L<Bencher> and L<bencher> (CLI) for more details.
+To display as an interactive HTML table on a browser, you can add option C<--format html+datatables>.
 
 =head1 HOMEPAGE
 
@@ -235,7 +240,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
